package com.jjt.biz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.BluetoothInfo;
import com.jjt.biz.service.IBluetoothInfoService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 蓝牙信息Controller
 * 
 * @author ruoyi
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/biz/bluetoothINfo")
public class BluetoothInfoController extends BaseController
{
    @Autowired
    private IBluetoothInfoService bluetoothInfoService;

    /**
     * 查询蓝牙信息列表
     */
    @PreAuthorize("@ss.hasPermi('biz:bluetoothINfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(BluetoothInfo bluetoothInfo)
    {
        startPage();
        List<BluetoothInfo> list = bluetoothInfoService.selectBluetoothInfoList(bluetoothInfo);
        return getDataTable(list);
    }

    /**
     * 导出蓝牙信息列表
     */
    @PreAuthorize("@ss.hasPermi('biz:bluetoothINfo:export')")
    @Log(title = "蓝牙信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BluetoothInfo bluetoothInfo)
    {
        List<BluetoothInfo> list = bluetoothInfoService.selectBluetoothInfoList(bluetoothInfo);
        ExcelUtil<BluetoothInfo> util = new ExcelUtil<BluetoothInfo>(BluetoothInfo.class);
        util.exportExcel(response, list, "蓝牙信息数据");
    }

    /**
     * 获取蓝牙信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:bluetoothINfo:query')")
    @GetMapping(value = "/{bInfoId}")
    public AjaxResult getInfo(@PathVariable("bInfoId") Long bInfoId)
    {
        return success(bluetoothInfoService.selectBluetoothInfoByBInfoId(bInfoId));
    }

    /**
     * 新增蓝牙信息
     */
    @PreAuthorize("@ss.hasPermi('biz:bluetoothINfo:add')")
    @Log(title = "蓝牙信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BluetoothInfo bluetoothInfo)
    {
        return toAjax(bluetoothInfoService.insertBluetoothInfo(bluetoothInfo));
    }

    /**
     * 修改蓝牙信息
     */
    @PreAuthorize("@ss.hasPermi('biz:bluetoothINfo:edit')")
    @Log(title = "蓝牙信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BluetoothInfo bluetoothInfo)
    {
        return toAjax(bluetoothInfoService.updateBluetoothInfo(bluetoothInfo));
    }

    /**
     * 删除蓝牙信息
     */
    @PreAuthorize("@ss.hasPermi('biz:bluetoothINfo:remove')")
    @Log(title = "蓝牙信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{bInfoIds}")
    public AjaxResult remove(@PathVariable Long[] bInfoIds)
    {
        return toAjax(bluetoothInfoService.deleteBluetoothInfoByBInfoIds(bInfoIds));
    }
}
