package com.jjt.biz.controller;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.jjt.common.config.RuoYiConfig;
import com.jjt.common.constant.Constants;
import com.jjt.common.utils.StringUtils;
import org.apache.commons.codec.digest.DigestUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.DeviceUpgrade;
import com.jjt.biz.service.IDeviceUpgradeService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 设备升级信息Controller
 *
 * @author ruoyi
 * @date 2023-07-10
 */
@RestController
@RequestMapping("/biz/upgrade")
public class DeviceUpgradeController extends BaseController {
    @Autowired
    private IDeviceUpgradeService deviceUpgradeService;

    /**
     * 查询设备升级信息列表
     */
    @PreAuthorize("@ss.hasPermi('biz:upgrade:list')")
    @GetMapping("/list")
    public TableDataInfo list(DeviceUpgrade deviceUpgrade) {
        startPage();
        List<DeviceUpgrade> list = deviceUpgradeService.selectDeviceUpgradeList(deviceUpgrade);
        return getDataTable(list);
    }

    /**
     * 导出设备升级信息列表
     */
    @PreAuthorize("@ss.hasPermi('biz:upgrade:export')")
    @Log(title = "设备升级信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DeviceUpgrade deviceUpgrade) {
        List<DeviceUpgrade> list = deviceUpgradeService.selectDeviceUpgradeList(deviceUpgrade);
        ExcelUtil<DeviceUpgrade> util = new ExcelUtil<DeviceUpgrade>(DeviceUpgrade.class);
        util.exportExcel(response, list, "设备升级信息数据");
    }

    /**
     * 获取设备升级信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:upgrade:query')")
    @GetMapping(value = "/{upId}")
    public AjaxResult getInfo(@PathVariable("upId") Long upId) {
        return success(deviceUpgradeService.selectDeviceUpgradeByUpId(upId));
    }

    /**
     * 新增设备升级信息
     */
    @PreAuthorize("@ss.hasPermi('biz:upgrade:add')")
    @Log(title = "设备升级信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DeviceUpgrade deviceUpgrade) throws IOException {
        String uri = deviceUpgrade.getPath();
        if (StringUtils.isNotEmpty(uri)) {
            uri = uri.substring(uri.indexOf(Constants.RESOURCE_PREFIX));
            String filePath = uri.replace(Constants.RESOURCE_PREFIX, RuoYiConfig.getProfile());
            String md5 = DigestUtils.md5Hex(Files.newInputStream(Paths.get(filePath)));
            deviceUpgrade.setMd5(md5);
        }
        return toAjax(deviceUpgradeService.insertDeviceUpgrade(deviceUpgrade));
    }

    /**
     * 修改设备升级信息
     */
    @PreAuthorize("@ss.hasPermi('biz:upgrade:edit')")
    @Log(title = "设备升级信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DeviceUpgrade deviceUpgrade) {
        return toAjax(deviceUpgradeService.updateDeviceUpgrade(deviceUpgrade));
    }

    /**
     * 删除设备升级信息
     */
    @PreAuthorize("@ss.hasPermi('biz:upgrade:remove')")
    @Log(title = "设备升级信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{upIds}")
    public AjaxResult remove(@PathVariable Long[] upIds) {
        return toAjax(deviceUpgradeService.deleteDeviceUpgradeByUpIds(upIds));
    }
}
