package com.jjt.biz.controller;

import com.alibaba.fastjson2.JSON;
import com.jjt.biz.domain.*;
import com.jjt.biz.service.IBluetoothInfoService;
import com.jjt.biz.service.IDeviceInfoService;
import com.jjt.biz.service.IVenueInfoService;
import com.jjt.biz.service.IWifiInfoService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.DateUtils;
import com.jjt.common.utils.StringUtils;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.framework.websocket.WebSocketUsers;
import com.jjt.system.service.ISysConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.time.DayOfWeek;
import java.time.LocalDate;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 蓝牙信息Controller
 *
 * @author ruoyi
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/index")
public class IndexController extends BaseController {
    @Resource
    private IBluetoothInfoService bluetoothInfoService;
    @Resource
    private IDeviceInfoService deviceInfoService;
    @Resource
    private IWifiInfoService wifiInfoService;
    @Resource
    private IVenueInfoService venueInfoService;
    @Resource
    private ISysConfigService configService;

    @GetMapping("/msg")
    public Map<String, Object> msg(InfoReq req) {
        Map<String, Object> params = new HashMap<>();
        params.put("beginTime", "xx");
        params.put("endTime", "yy");
        WebSocketUsers.sendMessageToUsersByText(JSON.toJSONString(params));
        return params;
    }

    /**
     * 首页信息
     */
    @GetMapping("/info")
    public Map<String, Object> info(InfoReq req) {
        LocalDate nowDate = LocalDate.now();
        String filter = "";
        if (req.getFilter() != null) {
            //为了兼容以前的代码，不至于程序报错，所以这样写
            filter = req.getFilter();
        }
         switch (filter) {
            case "1":
                //当天
                req.setStart(nowDate.toString());
                req.setEnd(nowDate.toString());
                break;
            case "2":
                //本周
                LocalDate monday = nowDate.with(DayOfWeek.MONDAY);
                req.setStart(monday.toString());
                req.setEnd(DateUtils.getDate());
                break;
            case "3":
                //本月
                LocalDate month1 = nowDate.withDayOfMonth(1);
                req.setStart(month1.toString());
                req.setEnd(nowDate.toString());
                break;
            case "4":
                //本年
                LocalDate year1 = nowDate.withDayOfYear(1);
                req.setStart(year1.toString());
                req.setEnd(nowDate.toString());
                break;
           /* case "5":
                //全部
                req.setStart("");
                req.setStart("");
                break;*/
            case "6":
                //自定义,直接使用前台传的不管
                break;
            default:
                //默认查询全部
                req.setStart("");
                req.setEnd("");
        }

        Map<String, Object> params = new HashMap<>();
        params.put("beginTime", req.getStart());
        params.put("endTime", req.getEnd());

        Map<String, Object> map = new HashMap<>(16);
        List deviceInfos = deviceInfoService.selectDeviceInfoList(new DeviceInfo());
        map.put("deviceNO", deviceInfos.size());

        //查询wifi数
        WifiInfo wifiInfo = new WifiInfo();
        wifiInfo.setParams(params);

        List<WifiInfo> wifiInfos = wifiInfoService.selectWifiInfoList(wifiInfo);
        List<WifiInfo> illegalWifi = wifiInfos.stream()
                .filter(bean -> bean.getIsIllegal().equals("Y"))
                .collect(Collectors.toList());
        map.put("totalWifiNO", wifiInfos.size());
        map.put("wifiNO", illegalWifi.size());

        //查询蓝牙数
        BluetoothInfo bluetoothInfo = new BluetoothInfo();
        bluetoothInfo.setParams(params);
        List<BluetoothInfo> bluetoothInfos = bluetoothInfoService.selectBluetoothInfoList(bluetoothInfo);

        List<BluetoothInfo> illegalBlue = bluetoothInfos.stream()
                .filter(bean -> bean.getIsIllegal().equals("Y"))
                .collect(Collectors.toList());
        map.put("totalBluetoothNO", bluetoothInfos.size());
        map.put("bluetoothNO", illegalBlue.size());
        List venueInfos = venueInfoService.selectVenueInfoList(new VenueInfo());
        map.put("venueNO", venueInfos.size());
        Integer precision = Integer.parseInt(configService.selectConfigByKey("custom.precision"));
        Map<String, List<WifiInfo>> wifiGroups = wifiInfos.stream().collect(Collectors.groupingBy(info -> fetchGroupWifi(info, precision)));
        Map<String, List<BluetoothInfo>> blueGroups = bluetoothInfos.stream().collect(Collectors.groupingBy(info -> fetchGroupBlue(info, precision)));


        List<InfoVO> infoVOS = new ArrayList<>();
        InfoVO vo;
        for (String s : wifiGroups.keySet()) {
            vo = new InfoVO();
            String[] ss = s.split("#");
            vo.setLat(ss[0]);
            vo.setLng(ss[1]);

            vo.setTotalWifi(wifiGroups.get(s).size());
            List<WifiInfo> wifiList = wifiGroups.get(s).stream()
                    .filter(bean -> bean.getIsIllegal().equals("Y"))
                    .collect(Collectors.toList());
            vo.setWifi(wifiList.size());
            if (blueGroups.get(s) != null) {
                //如果相同坐标下还有恶意蓝牙
                vo.setTotalBluetooth(blueGroups.get(s).size());
                List<BluetoothInfo> blueList = bluetoothInfos.stream()
                        .filter(bean -> bean.getIsIllegal().equals("Y"))
                        .collect(Collectors.toList());
                vo.setBluetooth(blueList.size());
            } else {
                vo.setTotalBluetooth(0);
                vo.setBluetooth(0);
            }

            if (vo.getWifi() >= 0 || vo.getBluetooth() > 0) {
                infoVOS.add(vo);
            }
        }

        for (String s : blueGroups.keySet()) {
            vo = new InfoVO();
            String[] ss = s.split("#");
            vo.setLat(ss[0]);
            vo.setLng(ss[1]);
            vo.setWifi(0);
            vo.setTotalWifi(0);
            vo.setTotalBluetooth(blueGroups.get(s).size());
            List<BluetoothInfo> blueList = bluetoothInfos.stream()
                    .filter(bean -> bean.getIsIllegal().equals("Y"))
                    .collect(Collectors.toList());
            vo.setBluetooth(blueList.size());

            if (vo.getWifi() >= 0 || vo.getBluetooth() > 0) {
                infoVOS.add(vo);
            }
        }

        map.put("info", infoVOS);

        return map;
    }

    /**
     * 组装分组条件
     */
    private static String fetchGroupWifi(WifiInfo info, int precision) {
        BigDecimal lat = new BigDecimal(info.getLat());
        BigDecimal lng = new BigDecimal(info.getLng());
        lat = lat.setScale(precision, RoundingMode.HALF_UP);
        lng = lng.setScale(precision, RoundingMode.HALF_UP);
        String key = lat + "#" + lng;
        return key;
    }

    /**
     * 组装分组条件
     */
    private static String fetchGroupBlue(BluetoothInfo info, int precision) {
        BigDecimal lat = new BigDecimal(info.getLat());
        BigDecimal lng = new BigDecimal(info.getLng());
        lat = lat.setScale(precision, RoundingMode.HALF_UP);
        lng = lng.setScale(precision, RoundingMode.HALF_UP);
        String key = lat + "#" + lng;
        return key;
    }

    /**
     * 首页信息
     */
    @GetMapping("/top")
    public List<TopVO> top() {
        List<TopVO> list = venueInfoService.selectTop10();
        if (list.size() == 0 || (list.size() > 0 && list.get(0).getBluetooth() == 0 && list.get(0).getWifi() == 0)) {
            list = new ArrayList<>();
            list.add(new TopVO("东安湖体育公园游泳跳水馆", 87, 84));
            list.add(new TopVO("东安湖体育公园多功能体育馆", 33, 80));
            list.add(new TopVO("凤凰山体育公园", 99, 89));
            list.add(new TopVO("高新体育中心体育馆", 75, 74));
            list.add(new TopVO("简阳文体中心游泳馆", 65, 78));
            list.add(new TopVO("简阳文体中心体育馆", 2, 23));
            list.add(new TopVO("四川大学望江校区体育馆", 78, 41));
            list.add(new TopVO("电子科技大学清水河校区体育馆", 49, 41));
            list.add(new TopVO("西南财大光华校区体育馆", 25, 60));
            list.add(new TopVO("西南交通大学犀浦校区体育馆", 32, 83));
        }
        return list;
    }

    /**
     * 首页信息
     */
    @GetMapping("/realTimeInfo")
    public List<RealTimeInfoVO> realTimeInfo() {
        List<RealTimeInfoVO> list = wifiInfoService.selectRealTimeInfoList();
        return list;
    }
}
