package com.jjt.biz.controller;

import java.nio.charset.StandardCharsets;
import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import com.jjt.biz.domain.BluetoothInfo;
import com.jjt.biz.domain.WifiInfo;
import com.jjt.biz.service.IBluetoothInfoService;
import com.jjt.biz.service.IWifiInfoService;
import com.jjt.biz.vo.IllegalVO;
import com.jjt.biz.vo.WifiInfoVO;
import com.jjt.common.utils.StringUtils;
import com.jjt.common.utils.sign.Base64;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.KeyInfo;
import com.jjt.biz.service.IKeyInfoService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 关键字Controller
 *
 * @author ruoyi
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/biz/keyInfo")
public class KeyInfoController extends BaseController {
    @Resource
    private IKeyInfoService keyInfoService;
    @Resource
    private IBluetoothInfoService bluetoothInfoService;
    @Resource
    private IWifiInfoService wifiInfoService;

    /**
     * 查询关键字列表
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(KeyInfo keyInfo) {
        startPage();
        List<KeyInfo> list = keyInfoService.selectKeyInfoList(keyInfo);
        return getDataTable(list);
    }

    /**
     * 查询关键字列表
     */
    @GetMapping("/replay")
    public AjaxResult replay() {
        List<KeyInfo> list = keyInfoService.selectKeyInfoList(new KeyInfo());
        List<WifiInfo> wifiInfos = wifiInfoService.selectWifiInfoList(new WifiInfo());
        wifiInfos.forEach(info -> {
            info.setIsIllegal("N");
            if (StringUtils.isNotEmpty(info.getAuthPage())) {
                IllegalVO illegal = isIllegal(list, info.getAuthPage());
                if (illegal.isIllegal()) {
                    info.setIsIllegal("Y");
                    info.setKeyType(illegal.getKeyType());
                }
                isIllegal(list, info.getSsid());
            }
            IllegalVO illegal = isIllegal(list, info.getSsid());
            if (illegal.isIllegal()) {
                info.setIsIllegal("Y");
                info.setKeyType(illegal.getKeyType());
            }
            wifiInfoService.updateWifiInfo(info);
        });


        List<BluetoothInfo> bluetoothInfos = bluetoothInfoService.selectBluetoothInfoList(new BluetoothInfo());

        bluetoothInfos.forEach(info -> {
            info.setIsIllegal("N");

            IllegalVO illegal = isIllegal(list, info.getName());
            if (illegal.isIllegal()) {
                info.setIsIllegal("Y");
                info.setKeyType(illegal.getKeyType());
            }
            illegal = isIllegal(list, info.getFileName());
            if (illegal.isIllegal()) {
                info.setIsIllegal("Y");
                info.setKeyType(illegal.getKeyType());
            }
            bluetoothInfoService.updateBluetoothInfo(info);
        });
        return AjaxResult.success();
    }

    private IllegalVO isIllegal(List<KeyInfo> keyInfoList, String content) {


        IllegalVO result = new IllegalVO();
        result.setIllegal(false);
        if (StringUtils.isEmpty(content)) {
            return result;
        }
        for (KeyInfo keyInfo : keyInfoList) {
            String[] keys = keyInfo.getKeyWords().split(",");
            for (String key : keys) {
                if (content.contains(key)) {
                    result.setIllegal(true);
                    result.setKeyType(keyInfo.getKeyType());
                    return result;
                }
            }
        }
        return result;
    }

    /**
     * 导出关键字列表
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:export')")
    @Log(title = "关键字", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, KeyInfo keyInfo) {
        List<KeyInfo> list = keyInfoService.selectKeyInfoList(keyInfo);
        ExcelUtil<KeyInfo> util = new ExcelUtil<KeyInfo>(KeyInfo.class);
        util.exportExcel(response, list, "关键字数据");
    }

    /**
     * 获取关键字详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:query')")
    @GetMapping(value = "/{keyId}")
    public AjaxResult getInfo(@PathVariable("keyId") Long keyId) {
        return success(keyInfoService.selectKeyInfoByKeyId(keyId));
    }

    /**
     * 新增关键字
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:add')")
    @Log(title = "关键字", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody KeyInfo keyInfo) {
        return toAjax(keyInfoService.insertKeyInfo(keyInfo));
    }

    /**
     * 修改关键字
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:edit')")
    @Log(title = "关键字", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody KeyInfo keyInfo) {
        return toAjax(keyInfoService.updateKeyInfo(keyInfo));
    }

    /**
     * 删除关键字
     */
    @PreAuthorize("@ss.hasPermi('biz:keyInfo:remove')")
    @Log(title = "关键字", businessType = BusinessType.DELETE)
    @DeleteMapping("/{keyIds}")
    public AjaxResult remove(@PathVariable Long[] keyIds) {
        return toAjax(keyInfoService.deleteKeyInfoByKeyIds(keyIds));
    }
}
