package com.jjt.biz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.VenueArea;
import com.jjt.biz.service.IVenueAreaService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 场馆区域Controller
 * 
 * @author ruoyi
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/biz/venueArea")
public class VenueAreaController extends BaseController
{
    @Autowired
    private IVenueAreaService venueAreaService;

    /**
     * 查询场馆区域列表
     */
    @PreAuthorize("@ss.hasPermi('biz:venueArea:list')")
    @GetMapping("/list")
    public TableDataInfo list(VenueArea venueArea)
    {
        startPage();
        List<VenueArea> list = venueAreaService.selectVenueAreaList(venueArea);
        return getDataTable(list);
    }

    /**
     * 导出场馆区域列表
     */
    @PreAuthorize("@ss.hasPermi('biz:venueArea:export')")
    @Log(title = "场馆区域", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, VenueArea venueArea)
    {
        List<VenueArea> list = venueAreaService.selectVenueAreaList(venueArea);
        ExcelUtil<VenueArea> util = new ExcelUtil<VenueArea>(VenueArea.class);
        util.exportExcel(response, list, "场馆区域数据");
    }

    /**
     * 获取场馆区域详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:venueArea:query')")
    @GetMapping(value = "/{areaId}")
    public AjaxResult getInfo(@PathVariable("areaId") Long areaId)
    {
        return success(venueAreaService.selectVenueAreaByAreaId(areaId));
    }

    /**
     * 新增场馆区域
     */
    @PreAuthorize("@ss.hasPermi('biz:venueArea:add')")
    @Log(title = "场馆区域", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody VenueArea venueArea)
    {
        return toAjax(venueAreaService.insertVenueArea(venueArea));
    }

    /**
     * 修改场馆区域
     */
    @PreAuthorize("@ss.hasPermi('biz:venueArea:edit')")
    @Log(title = "场馆区域", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody VenueArea venueArea)
    {
        return toAjax(venueAreaService.updateVenueArea(venueArea));
    }

    /**
     * 删除场馆区域
     */
    @PreAuthorize("@ss.hasPermi('biz:venueArea:remove')")
    @Log(title = "场馆区域", businessType = BusinessType.DELETE)
	@DeleteMapping("/{areaIds}")
    public AjaxResult remove(@PathVariable Long[] areaIds)
    {
        return toAjax(venueAreaService.deleteVenueAreaByAreaIds(areaIds));
    }
}
