package com.jjt.biz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.VenueInfo;
import com.jjt.biz.service.IVenueInfoService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 场馆基本信息Controller
 * 
 * @author ruoyi
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/biz/venueInfo")
public class VenueInfoController extends BaseController
{
    @Autowired
    private IVenueInfoService venueInfoService;

    /**
     * 查询场馆基本信息列表
     */
    @PreAuthorize("@ss.hasPermi('biz:venueInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(VenueInfo venueInfo)
    {
        startPage();
        List<VenueInfo> list = venueInfoService.selectVenueInfoList(venueInfo);
        return getDataTable(list);
    }

    /**
     * 导出场馆基本信息列表
     */
    @PreAuthorize("@ss.hasPermi('biz:venueInfo:export')")
    @Log(title = "场馆基本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, VenueInfo venueInfo)
    {
        List<VenueInfo> list = venueInfoService.selectVenueInfoList(venueInfo);
        ExcelUtil<VenueInfo> util = new ExcelUtil<VenueInfo>(VenueInfo.class);
        util.exportExcel(response, list, "场馆基本信息数据");
    }

    /**
     * 获取场馆基本信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:venueInfo:query')")
    @GetMapping(value = "/{venueId}")
    public AjaxResult getInfo(@PathVariable("venueId") Long venueId)
    {
        return success(venueInfoService.selectVenueInfoByVenueId(venueId));
    }

    /**
     * 新增场馆基本信息
     */
    @PreAuthorize("@ss.hasPermi('biz:venueInfo:add')")
    @Log(title = "场馆基本信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody VenueInfo venueInfo)
    {
        return toAjax(venueInfoService.insertVenueInfo(venueInfo));
    }

    /**
     * 修改场馆基本信息
     */
    @PreAuthorize("@ss.hasPermi('biz:venueInfo:edit')")
    @Log(title = "场馆基本信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody VenueInfo venueInfo)
    {
        return toAjax(venueInfoService.updateVenueInfo(venueInfo));
    }

    /**
     * 删除场馆基本信息
     */
    @PreAuthorize("@ss.hasPermi('biz:venueInfo:remove')")
    @Log(title = "场馆基本信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{venueIds}")
    public AjaxResult remove(@PathVariable Long[] venueIds)
    {
        return toAjax(venueInfoService.deleteVenueInfoByVenueIds(venueIds));
    }
}
