package com.jjt.biz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.WifiInfo;
import com.jjt.biz.service.IWifiInfoService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * WIFI信息Controller
 * 
 * @author ruoyi
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/biz/wifiInfo")
public class WifiInfoController extends BaseController
{
    @Autowired
    private IWifiInfoService wifiInfoService;

    /**
     * 查询WIFI信息列表
     */
    @PreAuthorize("@ss.hasPermi('biz:wifiInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(WifiInfo wifiInfo)
    {
        startPage();
        List<WifiInfo> list = wifiInfoService.selectWifiInfoList(wifiInfo);
        return getDataTable(list);
    }

    /**
     * 导出WIFI信息列表
     */
    @PreAuthorize("@ss.hasPermi('biz:wifiInfo:export')")
    @Log(title = "WIFI信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WifiInfo wifiInfo)
    {
        List<WifiInfo> list = wifiInfoService.selectWifiInfoList(wifiInfo);
        ExcelUtil<WifiInfo> util = new ExcelUtil<WifiInfo>(WifiInfo.class);
        util.exportExcel(response, list, "WIFI信息数据");
    }

    /**
     * 获取WIFI信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('biz:wifiInfo:query')")
    @GetMapping(value = "/{wifiInfoId}")
    public AjaxResult getInfo(@PathVariable("wifiInfoId") Long wifiInfoId)
    {
        return success(wifiInfoService.selectWifiInfoByWifiInfoId(wifiInfoId));
    }

    /**
     * 新增WIFI信息
     */
    @PreAuthorize("@ss.hasPermi('biz:wifiInfo:add')")
    @Log(title = "WIFI信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WifiInfo wifiInfo)
    {
        return toAjax(wifiInfoService.insertWifiInfo(wifiInfo));
    }

    /**
     * 修改WIFI信息
     */
    @PreAuthorize("@ss.hasPermi('biz:wifiInfo:edit')")
    @Log(title = "WIFI信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WifiInfo wifiInfo)
    {
        return toAjax(wifiInfoService.updateWifiInfo(wifiInfo));
    }

    /**
     * 删除WIFI信息
     */
    @PreAuthorize("@ss.hasPermi('biz:wifiInfo:remove')")
    @Log(title = "WIFI信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{wifiInfoIds}")
    public AjaxResult remove(@PathVariable Long[] wifiInfoIds)
    {
        return toAjax(wifiInfoService.deleteWifiInfoByWifiInfoIds(wifiInfoIds));
    }
}
