package com.jjt.biz.mapper;

import java.util.List;

import com.jjt.biz.domain.TopVO;
import com.jjt.biz.domain.VenueInfo;
import com.jjt.biz.domain.VenueArea;

/**
 * 场馆基本信息Mapper接口
 *
 * @author ruoyi
 * @date 2023-07-06
 */
public interface VenueInfoMapper {
    /**
     * 查询场馆基本信息
     *
     * @param venueId 场馆基本信息主键
     * @return 场馆基本信息
     */
    public VenueInfo selectVenueInfoByVenueId(Long venueId);

    /**
     * 查询场馆基本信息列表
     *
     * @param venueInfo 场馆基本信息
     * @return 场馆基本信息集合
     */
    public List<VenueInfo> selectVenueInfoList(VenueInfo venueInfo);

    /**
     * 新增场馆基本信息
     *
     * @param venueInfo 场馆基本信息
     * @return 结果
     */
    public int insertVenueInfo(VenueInfo venueInfo);

    /**
     * 修改场馆基本信息
     *
     * @param venueInfo 场馆基本信息
     * @return 结果
     */
    public int updateVenueInfo(VenueInfo venueInfo);

    /**
     * 删除场馆基本信息
     *
     * @param venueId 场馆基本信息主键
     * @return 结果
     */
    public int deleteVenueInfoByVenueId(Long venueId);

    /**
     * 批量删除场馆基本信息
     *
     * @param venueIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteVenueInfoByVenueIds(Long[] venueIds);

    /**
     * 批量删除场馆区域
     *
     * @param venueIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteVenueAreaByVenueIds(Long[] venueIds);

    /**
     * 批量新增场馆区域
     *
     * @param venueAreaList 场馆区域列表
     * @return 结果
     */
    public int batchVenueArea(List<VenueArea> venueAreaList);


    /**
     * 通过场馆基本信息主键删除场馆区域信息
     *
     * @param venueId 场馆基本信息ID
     * @return 结果
     */
    public int deleteVenueAreaByVenueId(Long venueId);

    /**
     * 查询Top10
     *
     * @return
     */
    public List<TopVO> selectTop10();
}
