package com.jjt.biz.service.impl;

import java.util.Date;
import java.util.List;

import org.apache.coyote.http11.upgrade.UpgradeInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.jjt.biz.mapper.DeviceUpgradeMapper;
import com.jjt.biz.domain.DeviceUpgrade;
import com.jjt.biz.service.IDeviceUpgradeService;

import javax.annotation.Resource;

/**
 * 设备升级信息Service业务层处理
 *
 * @author ruoyi
 * @date 2023-07-10
 */
@Service
public class DeviceUpgradeServiceImpl implements IDeviceUpgradeService {
    @Resource
    private DeviceUpgradeMapper deviceUpgradeMapper;

    /**
     * 查询设备升级信息
     *
     * @param upId 设备升级信息主键
     * @return 设备升级信息
     */
    @Override
    public DeviceUpgrade selectDeviceUpgradeByUpId(Long upId) {
        return deviceUpgradeMapper.selectDeviceUpgradeByUpId(upId);
    }

    /**
     * 查询设备升级信息列表
     *
     * @param deviceUpgrade 设备升级信息
     * @return 设备升级信息
     */
    @Override
    public List<DeviceUpgrade> selectDeviceUpgradeList(DeviceUpgrade deviceUpgrade) {
        return deviceUpgradeMapper.selectDeviceUpgradeList(deviceUpgrade);
    }

    /**
     * 新增设备升级信息
     *
     * @param deviceUpgrade 设备升级信息
     * @return 结果
     */
    @Override
    public int insertDeviceUpgrade(DeviceUpgrade deviceUpgrade) {
        deviceUpgrade.setCreatedTime(new Date());
        return deviceUpgradeMapper.insertDeviceUpgrade(deviceUpgrade);
    }

    /**
     * 修改设备升级信息
     *
     * @param deviceUpgrade 设备升级信息
     * @return 结果
     */
    @Override
    public int updateDeviceUpgrade(DeviceUpgrade deviceUpgrade) {
        return deviceUpgradeMapper.updateDeviceUpgrade(deviceUpgrade);
    }

    /**
     * 批量删除设备升级信息
     *
     * @param upIds 需要删除的设备升级信息主键
     * @return 结果
     */
    @Override
    public int deleteDeviceUpgradeByUpIds(Long[] upIds) {
        return deviceUpgradeMapper.deleteDeviceUpgradeByUpIds(upIds);
    }

    /**
     * 删除设备升级信息信息
     *
     * @param upId 设备升级信息主键
     * @return 结果
     */
    @Override
    public int deleteDeviceUpgradeByUpId(Long upId) {
        return deviceUpgradeMapper.deleteDeviceUpgradeByUpId(upId);
    }

    /**
     * 获取最新一条记录
     *
     * @return upd
     */
    @Override
    public DeviceUpgrade selectDeviceUpgradeLastOne() {
        return deviceUpgradeMapper.selectDeviceUpgradeLastOne();
    }
}
