package com.jjt.biz.service.impl;

import java.util.List;

import com.jjt.biz.domain.TopVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import com.jjt.common.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;
import com.jjt.biz.domain.VenueArea;
import com.jjt.biz.mapper.VenueInfoMapper;
import com.jjt.biz.domain.VenueInfo;
import com.jjt.biz.service.IVenueInfoService;

/**
 * 场馆基本信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-06
 */
@Service
public class VenueInfoServiceImpl implements IVenueInfoService 
{
    @Autowired
    private VenueInfoMapper venueInfoMapper;

    /**
     * 查询场馆基本信息
     * 
     * @param venueId 场馆基本信息主键
     * @return 场馆基本信息
     */
    @Override
    public VenueInfo selectVenueInfoByVenueId(Long venueId)
    {
        return venueInfoMapper.selectVenueInfoByVenueId(venueId);
    }

    /**
     * 查询场馆基本信息列表
     * 
     * @param venueInfo 场馆基本信息
     * @return 场馆基本信息
     */
    @Override
    public List<VenueInfo> selectVenueInfoList(VenueInfo venueInfo)
    {
        return venueInfoMapper.selectVenueInfoList(venueInfo);
    }

    /**
     * 查询Top10
     *
     * @return
     */
    @Override
    public List<TopVO> selectTop10() {
        return venueInfoMapper.selectTop10();
    }

    /**
     * 新增场馆基本信息
     * 
     * @param venueInfo 场馆基本信息
     * @return 结果
     */
    @Transactional
    @Override
    public int insertVenueInfo(VenueInfo venueInfo)
    {
        int rows = venueInfoMapper.insertVenueInfo(venueInfo);
        insertVenueArea(venueInfo);
        return rows;
    }

    /**
     * 修改场馆基本信息
     * 
     * @param venueInfo 场馆基本信息
     * @return 结果
     */
    @Transactional
    @Override
    public int updateVenueInfo(VenueInfo venueInfo)
    {
        venueInfoMapper.deleteVenueAreaByVenueId(venueInfo.getVenueId());
        insertVenueArea(venueInfo);
        return venueInfoMapper.updateVenueInfo(venueInfo);
    }

    /**
     * 批量删除场馆基本信息
     * 
     * @param venueIds 需要删除的场馆基本信息主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteVenueInfoByVenueIds(Long[] venueIds)
    {
        venueInfoMapper.deleteVenueAreaByVenueIds(venueIds);
        return venueInfoMapper.deleteVenueInfoByVenueIds(venueIds);
    }

    /**
     * 删除场馆基本信息信息
     * 
     * @param venueId 场馆基本信息主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteVenueInfoByVenueId(Long venueId)
    {
        venueInfoMapper.deleteVenueAreaByVenueId(venueId);
        return venueInfoMapper.deleteVenueInfoByVenueId(venueId);
    }

    /**
     * 新增场馆区域信息
     * 
     * @param venueInfo 场馆基本信息对象
     */
    public void insertVenueArea(VenueInfo venueInfo)
    {
        List<VenueArea> venueAreaList = venueInfo.getVenueAreaList();
        Long venueId = venueInfo.getVenueId();
        if (StringUtils.isNotNull(venueAreaList))
        {
            List<VenueArea> list = new ArrayList<VenueArea>();
            for (VenueArea venueArea : venueAreaList)
            {
                venueArea.setVenueId(venueId);
                list.add(venueArea);
            }
            if (list.size() > 0)
            {
                venueInfoMapper.batchVenueArea(list);
            }
        }
    }
}
